#ifdef GL_ES
#define LOWP lowp
    precision mediump float;
#else
    #define LOWP
#endif

varying LOWP vec4 v_color;
varying vec2 v_texCoords;

uniform sampler2D u_texture;
uniform vec2 uv_offset;
uniform vec2 uv_repeat;
uniform float time;

vec4 back_color = vec4(1,1,1,0);
vec4 front_color = vec4(1,1,1,1);


float Hash(vec2 p)
{
    float h = dot(p, vec2(17.1, 311.7));
    return -1.0 + 2.0 * fract(sin(h) * 4358.5453);
}


float Noise(vec2 p)
{
    vec2 i = floor(p);
    vec2 f = fract(p);
    vec2 u = f * f * (3.0 - 2.0 * f);

    return mix(mix(Hash(i + vec2(0.0, 0.0)),
                   Hash(i + vec2(1.0, 0.0)), u.x),
               mix(Hash(i + vec2(0.0, 1.0)),
                   Hash(i + vec2(1.0, 1.0)), u.x), u.y);

}

float Voronoi(vec2 x)
{
    ivec2 p = ivec2(floor(x));
    vec2  f = fract(x);

    float res = 8.0;
    for(int j = -1; j <= 1; ++j)
        for(int i = -1; i <= 1; ++i) {
        ivec2 b = ivec2(i, j);
        vec2  r = vec2(b) - f + 0.5 + 0.4 * sin(time + 6.2831 * Noise(vec2(p + b)));
        float d = dot(r, r);
        res = min(res, d);
    }
    return sqrt(res);
}

vec3 VoronoiFn(vec2 x)
{
    ivec2 p = ivec2(floor(x));
    vec2 f = fract(x);

    float f1 = 18.0;
    float f2 = 18.0;
    float f3 = 18.0;
    for (int j = -1; j <= 1; ++ j) {
        for (int i = -1; i <= 1; ++ i) {
            ivec2 b = ivec2(i, j);
            vec2 r = vec2(b) + 0.5 + 0.4 * sin(time + 6.2831 * Hash(vec2(p + b))) - f;;
            float d = dot(r, r);

            if (d < f1) {
                f3 = f2;
                f2 = f1;
                f1 = d;
            } else if (d < f2) {
                f3 = f2;
                f2 = d;
            } else if (d < f3) {
                f3 = d;
            }
        }
    }
    return vec3(f1, f2, f3);
}

float makeDisc(vec2 p, float b, float r) {
	return smoothstep(r + b, r - b, sqrt(dot(p, p)));
}

void main()
{
    vec2 disc_center = vec2(0.5, 0.5);
    vec2 diskpos = v_texCoords;
    diskpos -= disc_center;


    gl_FragColor = mix(back_color, front_color, makeDisc(diskpos, 0.4, 0.1)) * v_color ;
}
